#include "math.i"
//import Math;

Math::Math()
:
    d_add(d_util)
{}
